@@ -74,7 +74,7 @@
     <message>
         <location filename="../../converter_window.cc" line="110"/>
         <source>shredded suet</source>
-        <translation type="unfinished"></translation>
+        <translation>suif râpé</translation>
     </message>
     <message>
         <location filename="../../converter_window.cc" line="111"/>
@@ -109,7 +109,7 @@
     <message>
         <location filename="../../converter_window.cc" line="117"/>
         <source>sultana</source>
-        <translation type="unfinished"></translation>
+        <translation>sultane</translation>
     </message>
     <message>
         <location filename="../../converter_window.cc" line="118"/>
@@ -328,7 +328,7 @@
     <message>
         <location filename="../../edit_dialog.ui" line="415"/>
         <source>carton</source>
-        <translation type="unfinished"></translation>
+        <translation>carton</translation>
     </message>
     <message>
         <location filename="../../edit_dialog.ui" line="420"/>
@@ -535,15 +535,40 @@
         <translation>US-ASCII</translation>
     </message>
     <message>
-        <location filename="../../export_dialog.ui" line="104"/>
+        <location filename="../../export_dialog.ui" line="74"/>
+        <source>Error Fi&amp;le</source>
+        <translation>Fi&amp;chier d&apos;erreur</translation>
+    </message>
+    <message>
+        <location filename="../../export_dialog.ui" line="92"/>
+        <source>/tmp/errors.mmf</source>
+        <translation>/tmp/errors.mmf</translation>
+    </message>
+    <message>
+        <location filename="../../export_dialog.ui" line="102"/>
+        <source>&amp;Select error file</source>
+        <translation>&amp;Sélectionner le fichier d&apos;erreurs</translation>
+    </message>
+    <message>
+        <location filename="../../export_dialog.ui" line="141"/>
         <source>Proceed with selection of output file</source>
         <translation>Sélectionner le fichier à enregistrer</translation>
     </message>
     <message>
-        <location filename="../../export_dialog.ui" line="111"/>
+        <location filename="../../export_dialog.ui" line="148"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuler</translation>
     </message>
+    <message>
+        <location filename="../../export_dialog.cc" line="42"/>
+        <source>Select Error File</source>
+        <translation>Sélectionner le fichier d&apos;erreurs</translation>
+    </message>
+    <message>
+        <location filename="../../export_dialog.cc" line="42"/>
+        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
+        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Texte (*.txt *.TXT);;Tous les fichiers (*)</translation>
+    </message>
 </context>
 <context>
     <name>ImportDialog</name>
@@ -608,14 +633,13 @@
         <translation>&amp;Annuler</translation>
     </message>
     <message>
-        <location filename="../../import_dialog.cc" line="30"/>
         <source>errors.mmf</source>
-        <translation>errors.mmf</translation>
+        <translation type="vanished">errors.mmf</translation>
     </message>
     <message>
         <location filename="../../import_dialog.cc" line="42"/>
         <source>Select Error File</source>
-        <translation type="unfinished">Sélectionner le fichier d&apos;erreurs</translation>
+        <translation>Sélectionner le fichier d&apos;erreurs</translation>
     </message>
     <message>
         <location filename="../../import_dialog.cc" line="42"/>
@@ -698,7 +722,7 @@
     <message>
         <location filename="../../main_window.ui" line="74"/>
         <source>&amp;Category</source>
-        <translation type="unfinished">&amp;Catégorie</translation>
+        <translation>&amp;Catégorie</translation>
     </message>
     <message>
         <location filename="../../main_window.ui" line="84"/>
@@ -736,358 +760,400 @@
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="213"/>
+        <location filename="../../main_window.ui" line="214"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="220"/>
+        <location filename="../../main_window.ui" line="221"/>
         <source>Edit</source>
         <translation>Edition</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="234"/>
+        <location filename="../../main_window.ui" line="236"/>
         <source>Tool Bar</source>
         <translation>Barre d&apos;outils</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="260"/>
+        <location filename="../../main_window.ui" line="264"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="263"/>
+        <location filename="../../main_window.ui" line="267"/>
         <source>Exit application</source>
         <translation>Quitter l&apos;application</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="266"/>
+        <location filename="../../main_window.ui" line="270"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="275"/>
+        <location filename="../../main_window.ui" line="279"/>
         <source>&amp;Import recipes</source>
         <translation>&amp;Importer des recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="278"/>
+        <location filename="../../main_window.ui" line="282"/>
         <source>Read MealMaster recipes from files</source>
         <translation>Ouvrir des recettes MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="281"/>
+        <location filename="../../main_window.ui" line="285"/>
         <source>Ctrl+I</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+I</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="290"/>
+        <location filename="../../main_window.ui" line="294"/>
         <source>Print p&amp;review</source>
         <translation>Aperçu avant i&amp;mpression</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="293"/>
+        <location filename="../../main_window.ui" line="297"/>
         <source>Print preview of current recipe</source>
         <translation>Aperçu de la recette courante avant impression</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="296"/>
+        <location filename="../../main_window.ui" line="300"/>
         <source>Ctrl+R</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="305"/>
+        <location filename="../../main_window.ui" line="309"/>
         <source>&amp;Print recipe</source>
         <translation>&amp;Imprimer la recette</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="308"/>
+        <location filename="../../main_window.ui" line="312"/>
         <source>Print current recipe</source>
         <translation>Imprimer la recette courante</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="311"/>
+        <location filename="../../main_window.ui" line="315"/>
         <source>Ctrl+P</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="320"/>
+        <location filename="../../main_window.ui" line="324"/>
         <source>A&amp;bout AnyMeal</source>
         <translation>A &amp;propos d&apos;Anymeal</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="323"/>
+        <location filename="../../main_window.ui" line="327"/>
         <source>Ctrl+B</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+B</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="332"/>
+        <location filename="../../main_window.ui" line="336"/>
         <source>&amp;Delete recipes</source>
         <translation>&amp;Supprimer les recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="335"/>
+        <location filename="../../main_window.ui" line="339"/>
         <source>Delete selected recipes</source>
         <translation>Supprimer les recettes sélectionnées</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="338"/>
+        <location filename="../../main_window.ui" line="342"/>
         <source>Del</source>
         <translation>Supp.</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="347"/>
+        <location filename="../../main_window.ui" line="351"/>
         <source>Exp&amp;ort recipes</source>
         <translation>Exp&amp;orter des recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="350"/>
+        <location filename="../../main_window.ui" line="354"/>
         <source>Write MealMaster recipes to file</source>
         <translation>Enregistrer des recettes MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="353"/>
+        <location filename="../../main_window.ui" line="357"/>
         <source>Ctrl+O</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="362"/>
+        <location filename="../../main_window.ui" line="366"/>
         <source>&amp;Edit Recipe</source>
         <translation>&amp;Modifier la recette</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="365"/>
+        <location filename="../../main_window.ui" line="369"/>
         <source>Edit current recipe</source>
         <translation>Modifier la recette courante</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="368"/>
+        <location filename="../../main_window.ui" line="372"/>
         <source>Ctrl+E</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="377"/>
+        <location filename="../../main_window.ui" line="381"/>
         <source>Collect &amp;Garbage</source>
-        <translation type="unfinished"></translation>
+        <translation>Ramasser les Ord&amp;ures</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="380"/>
+        <location filename="../../main_window.ui" line="384"/>
         <source>Delete unused categories and ingredients</source>
         <translation>Supprimer les catégories et ingrédients inutilisés</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="383"/>
+        <location filename="../../main_window.ui" line="387"/>
         <source>Ctrl+G</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+U</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="392"/>
+        <location filename="../../main_window.ui" line="396"/>
         <source>Add &amp;to Category</source>
         <translation>Ajou&amp;ter à une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="395"/>
+        <location filename="../../main_window.ui" line="399"/>
         <source>Add selected recipes to a category</source>
-        <translation>Ajouter à une catégorie les recettes sélectionnées</translation>
+        <translation>Ajouter à une ca&amp;tégorie les recettes sélectionnées</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="398"/>
+        <location filename="../../main_window.ui" line="402"/>
         <source>Ctrl+T</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+T</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="407"/>
+        <location filename="../../main_window.ui" line="411"/>
         <source>&amp;Remove from Category</source>
         <translation>&amp;Retirer d&apos;une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="410"/>
+        <location filename="../../main_window.ui" line="414"/>
         <source>Ctrl+D</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="419"/>
+        <location filename="../../main_window.ui" line="423"/>
         <source>Open Co&amp;nverter Window</source>
         <translation>Ouvrir le co&amp;nvertisseur</translation>
     </message>
     <message>
-        <location filename="../../main_window.ui" line="422"/>
-        <source>Ctrl+N</source>
-        <translation type="unfinished"></translation>
+        <location filename="../../main_window.ui" line="426"/>
+        <source>Ctrl+U</source>
+        <translation>Ctrl+U</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="90"/>
+        <location filename="../../main_window.ui" line="453"/>
+        <source>Ctrl+N</source>
+        <translation>Ctrl+N</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="435"/>
+        <source>Remove duplicates</source>
+        <translation>Supprimer les doublons</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="438"/>
+        <source>Remove duplicates in selected recipes</source>
+        <translation>Supprimer les doublons dans les recettes sélectionnées</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="447"/>
+        <source>New</source>
+        <translation>Nouveau</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.ui" line="450"/>
+        <source>New recipe</source>
+        <translation>Nouvelle recette</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="92"/>
         <source>Error Opening Database</source>
         <translation>Erreur d&apos;ouverture de la base de données</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="96"/>
+        <location filename="../../main_window.cc" line="98"/>
         <source>Showing %1 recipes ...</source>
         <translation>Affiche %1 recettes ...</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="107"/>
+        <location filename="../../main_window.cc" line="108"/>
         <source>Import MealMaster Files</source>
         <translation>Importer des fichiers MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="107"/>
-        <location filename="../../main_window.cc" line="423"/>
+        <location filename="../../main_window.cc" line="108"/>
+        <location filename="../../main_window.cc" line="438"/>
         <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
         <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Texte (*.txt *.TXT);;Tous les fichiers (*)</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="113"/>
+        <location filename="../../main_window.cc" line="114"/>
         <source>Importing files ...</source>
         <translation>Importation en cours</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="113"/>
-        <location filename="../../main_window.cc" line="429"/>
+        <location filename="../../main_window.cc" line="114"/>
+        <location filename="../../main_window.cc" line="445"/>
+        <location filename="../../main_window.cc" line="546"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="122"/>
+        <location filename="../../main_window.cc" line="123"/>
         <source>%1 imported and %2 failed ...</source>
         <translation>%1 importées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="132"/>
+        <location filename="../../main_window.cc" line="137"/>
         <source>Rejected recipe: </source>
         <translation>Recette rejetée:</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="137"/>
-        <location filename="../../main_window.cc" line="449"/>
+        <location filename="../../main_window.cc" line="142"/>
+        <location filename="../../main_window.cc" line="469"/>
+        <location filename="../../main_window.cc" line="477"/>
         <source>Error writing to file </source>
         <translation>Erreur d&apos;écriture</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="158"/>
+        <location filename="../../main_window.cc" line="163"/>
         <source>Recipes Imported</source>
         <translation>Recettes importées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="158"/>
+        <location filename="../../main_window.cc" line="163"/>
         <source>%1 imported and %2 failed.</source>
         <translation>%1 importées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="162"/>
+        <location filename="../../main_window.cc" line="167"/>
         <source>Error While Importing</source>
         <translation>Erreur lors de l&apos;import</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="173"/>
+        <location filename="../../main_window.cc" line="178"/>
         <source>Edit current recipe, a copy of the recipe, a new recipe, or cancel?</source>
         <translation>Modifier la recette courante, créer une copie, une nouvelle recette ou annuler?</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="174"/>
+        <location filename="../../main_window.cc" line="179"/>
         <source>&amp;Edit Current</source>
         <translation>Modifier la r&amp;ecette courante</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="175"/>
+        <location filename="../../main_window.cc" line="180"/>
         <source>Edit C&amp;opy</source>
         <translation>Créer une c&amp;opie</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="176"/>
+        <location filename="../../main_window.cc" line="181"/>
         <source>Edit &amp;New</source>
         <translation>Créer une &amp;nouvelle recette</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="177"/>
+        <location filename="../../main_window.cc" line="182"/>
         <source>&amp;Cancel</source>
-        <translation type="unfinished">&amp;Annuler</translation>
+        <translation>&amp;Annuler</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="234"/>
+        <location filename="../../main_window.cc" line="250"/>
         <source>Error While Updating Recipe</source>
         <translation>Erreur lors de la mise à jour</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="259"/>
+        <location filename="../../main_window.cc" line="275"/>
         <source>Error Adding Recipes to Category</source>
         <translation>Erreur lors de l&apos;ajout de recettes à une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="285"/>
+        <location filename="../../main_window.cc" line="301"/>
         <source>Error Removing Recipes from Category</source>
         <translation>Erreur lors du retrait de recettes d&apos;une catégorie</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="304"/>
+        <location filename="../../main_window.cc" line="320"/>
         <source>Error Collecting Garbage</source>
-        <translation type="unfinished"></translation>
+        <translation>Erreur lors de la collecte des déchets</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="313"/>
+        <location filename="../../main_window.cc" line="329"/>
         <source>About AnyMeal %1</source>
         <translation>A propos d&apos;Anymeal %1</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="358"/>
+        <location filename="../../main_window.cc" line="374"/>
         <source>Error Filtering Recipes</source>
         <translation>Erreur lors du filtrage des recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="372"/>
+        <location filename="../../main_window.cc" line="388"/>
         <source>Error Resetting Selection</source>
         <translation>Erreur de réinitialisation de la sélection</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="392"/>
+        <location filename="../../main_window.cc" line="408"/>
         <source>Error fetching recipe</source>
         <translation>Erreur lors de la recherche</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="423"/>
+        <location filename="../../main_window.cc" line="438"/>
         <source>Export MealMaster File</source>
         <translation>Exporter un fichier MealMaster</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="429"/>
+        <location filename="../../main_window.cc" line="445"/>
         <source>Exporting recipes ...</source>
         <translation>Exportation en cours</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="452"/>
+        <location filename="../../main_window.cc" line="464"/>
+        <source>Failed recipe: </source>
+        <translation>Recette ratée:</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="480"/>
         <source>%1 exported and %2 failed ...</source>
         <translation>%1 exportées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="455"/>
+        <location filename="../../main_window.cc" line="483"/>
         <source>Recipes Exported</source>
         <translation>Recettes exportées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="455"/>
+        <location filename="../../main_window.cc" line="483"/>
         <source>%1 exported and %2 failed.</source>
         <translation>%1 exportées et %2 échouées</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="459"/>
+        <location filename="../../main_window.cc" line="487"/>
         <source>Error While Exporting</source>
         <translation>Erreur lors de l&apos;export</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="467"/>
+        <location filename="../../main_window.cc" line="495"/>
         <source>Delete Recipes</source>
         <translation>Supprimer les recettes</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="467"/>
+        <location filename="../../main_window.cc" line="495"/>
         <source>Do you want to delete the selected recipes?</source>
         <translation>Voulez-vous supprimer les recettes sélectionnées?</translation>
     </message>
     <message>
-        <location filename="../../main_window.cc" line="486"/>
+        <location filename="../../main_window.cc" line="514"/>
         <source>Error Deleting Recipes</source>
         <translation>Erreur lors de la suppression</translation>
     </message>
+    <message>
+        <location filename="../../main_window.cc" line="546"/>
+        <source>Detecting duplicates ...</source>
+        <translation>Détection des doublons...</translation>
+    </message>
+    <message>
+        <location filename="../../main_window.cc" line="549"/>
+        <source>Found %1 duplicates ...</source>
+        <translation>J&apos;ai trouvé %1 doublons...</translation>
+    </message>
 </context>
 <context>
     <name>recipe</name>
@@ -1109,17 +1175,17 @@
     <message>
         <location filename="../../html.cc" line="199"/>
         <source>amount</source>
-        <translation type="unfinished">quantité</translation>
+        <translation>quantité</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="200"/>
         <source>unit</source>
-        <translation type="unfinished">unité</translation>
+        <translation>unité</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="201"/>
         <source>ingredient</source>
-        <translation type="unfinished">ingrédient</translation>
+        <translation>ingrédient</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="221"/>
@@ -1137,22 +1203,22 @@
     <message>
         <location filename="../../html.cc" line="61"/>
         <source>small</source>
-        <translation type="unfinished">petit</translation>
+        <translation>petit</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="62"/>
         <source>medium</source>
-        <translation type="unfinished">moyen</translation>
+        <translation>moyen</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="63"/>
         <source>large</source>
-        <translation type="unfinished">large</translation>
+        <translation>grand</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="64"/>
         <source>can</source>
-        <translation type="unfinished">canette</translation>
+        <translation>canette</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="65"/>
@@ -1162,12 +1228,12 @@
     <message>
         <location filename="../../html.cc" line="66"/>
         <source>pinch</source>
-        <translation type="unfinished">pincée</translation>
+        <translation>pincée</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="67"/>
         <source>drop</source>
-        <translation type="unfinished">goutte</translation>
+        <translation>goutte</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="68"/>
@@ -1177,7 +1243,7 @@
     <message>
         <location filename="../../html.cc" line="69"/>
         <source>carton</source>
-        <translation type="unfinished"></translation>
+        <translation>carton</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="70"/>
@@ -1187,109 +1253,109 @@
     <message>
         <location filename="../../html.cc" line="71"/>
         <source>slice</source>
-        <translation type="unfinished">tranche</translation>
+        <translation>tranche</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="72"/>
         <source>each</source>
-        <translation type="unfinished">chaque</translation>
+        <translation>chaque</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="73"/>
         <location filename="../../html.cc" line="74"/>
         <source>teaspoon</source>
-        <translation type="unfinished">cc</translation>
+        <translation>cc</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="75"/>
         <location filename="../../html.cc" line="76"/>
         <source>tablespoon</source>
-        <translation type="unfinished">cs</translation>
+        <translation>cs</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="77"/>
         <source>fluid ounce</source>
-        <translation type="unfinished">once liquide</translation>
+        <translation>once liquide</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="78"/>
         <source>cup</source>
-        <translation type="unfinished">tasse</translation>
+        <translation>tasse</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="79"/>
         <source>pint</source>
-        <translation type="unfinished">pinte</translation>
+        <translation>pinte</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="80"/>
         <source>quart</source>
-        <translation type="unfinished">quart</translation>
+        <translation>quart</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="81"/>
         <source>gallon</source>
-        <translation type="unfinished">gallon</translation>
+        <translation>gallon</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="82"/>
         <source>ounce</source>
-        <translation type="unfinished">once</translation>
+        <translation>once</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="83"/>
         <source>pound</source>
-        <translation type="unfinished">livre</translation>
+        <translation>livre</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="84"/>
         <source>milliliter</source>
-        <translation type="unfinished">ml</translation>
+        <translation>ml</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="85"/>
         <source>cubic cm</source>
-        <translation type="unfinished">cc</translation>
+        <translation>cc</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="86"/>
         <source>centiliter</source>
-        <translation type="unfinished">cl</translation>
+        <translation>cl</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="87"/>
         <source>deciliter</source>
-        <translation type="unfinished">dl</translation>
+        <translation>dl</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="88"/>
         <source>liter</source>
-        <translation type="unfinished">l</translation>
+        <translation>l</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="89"/>
         <source>milligram</source>
-        <translation type="unfinished">mg</translation>
+        <translation>mg</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="90"/>
         <source>centigram</source>
-        <translation type="unfinished">cg</translation>
+        <translation>cg</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="91"/>
         <source>decigram</source>
-        <translation type="unfinished">dg</translation>
+        <translation>dg</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="92"/>
         <source>gram</source>
-        <translation type="unfinished">g</translation>
+        <translation>g</translation>
     </message>
     <message>
         <location filename="../../html.cc" line="93"/>
         <source>kilogram</source>
-        <translation type="unfinished">kg</translation>
+        <translation>kg</translation>
     </message>
 </context>
 </TS>
