@@ -1,5 +1,5 @@
 /* AnyMeal recipe management software
-   Copyright (C) 2021 Jan Wedekind
+   Copyright (C) 2021, 2023 Jan Wedekind
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 #include <cassert>
 #include <fstream>
 #include <sstream>
+#include <set>
 #include <unistd.h>
 #include <QtCore/QStandardPaths>
 #include <QtCore/QStringListModel>
@@ -25,8 +26,6 @@
 #include <QtPrintSupport/QPrintPreviewDialog>
 #include <QtPrintSupport/QPrintDialog>
 #include "main_window.hh"
-#include "import_dialog.hh"
-#include "export_dialog.hh"
 #include "edit_dialog.hh"
 #include "category_dialog.hh"
 #include "partition.hh"
@@ -40,9 +39,11 @@
 using namespace std;
 
 MainWindow::MainWindow(QWidget *parent):
-  QMainWindow(parent), m_converter_window(this), m_titles_model(NULL), m_categories_model(NULL), m_categories_completer(NULL)
+  QMainWindow(parent), m_converter_window(this), m_import_dialog(this), m_export_dialog(this),
+  m_titles_model(NULL), m_categories_model(NULL), m_categories_completer(NULL)
 {
   m_ui.setupUi(this);
+  connect(m_ui.action_new, &QAction::triggered, this, &MainWindow::new_recipe);
   connect(m_ui.action_import, &QAction::triggered, this, &MainWindow::import);
   connect(m_ui.action_delete, &QAction::triggered, this, &MainWindow::delete_recipes);
   connect(m_ui.action_export, &QAction::triggered, this, &MainWindow::export_recipes);
@@ -51,6 +52,7 @@ MainWindow::MainWindow(QWidget *parent):
   connect(m_ui.action_edit, &QAction::triggered, this, &MainWindow::edit);
   connect(m_ui.action_add_to_category, &QAction::triggered, this, &MainWindow::add_to_category);
   connect(m_ui.action_remove_from_category, &QAction::triggered, this, &MainWindow::remove_from_category);
+  connect(m_ui.action_deduplicate, &QAction::triggered, this, &MainWindow::remove_duplicates);
   connect(m_ui.action_collect_garbage, &QAction::triggered, this, &MainWindow::collect_garbage);
   connect(m_ui.action_open_converter, &QAction::triggered, this, &MainWindow::open_converter);
   connect(m_ui.action_about, &QAction::triggered, this, &MainWindow::about);
@@ -99,17 +101,16 @@ void MainWindow::show_num_recipes(void) {
 void MainWindow::import(void) {
   bool transaction = false;
   try {
-    ImportDialog import_dialog(this);
-    int result = import_dialog.exec();
+    int result = m_import_dialog.exec();
     if (result == QDialog::Accepted) {
-      Recoder recoder((import_dialog.encoding() + "..UTF-8").c_str());
+      Recoder recoder(m_import_dialog.encoding().c_str(), "UTF-8");
       QStringList result =
         QFileDialog::getOpenFileNames(this, tr("Import MealMaster Files"), "", tr("MealMaster (*.mm *.MM *.mmf *.MMF);;"
                                       "Text (*.txt *.TXT);;All files (*)"));
       if (!result.isEmpty()) {
         int success = 0;
         int failed = 0;
-        ofstream error_file(import_dialog.error_file().c_str(), ofstream::binary);
+        ofstream error_file(m_import_dialog.error_file().c_str(), ofstream::binary);
         QProgressDialog progress(tr("Importing files ..."), tr("Cancel"), 0, result.size() * 100, this);
         progress.setWindowModality(Qt::WindowModal);
         for (int i=0; i<result.size(); i++) {
@@ -124,7 +125,11 @@ void MainWindow::import(void) {
             istringstream s(*recipe);
             try {
               Recipe result = parse_mealmaster(s);
-              Recipe recoded = recoder.process_recipe(result);
+              Recipe recoded;
+              if (m_import_dialog.encoding() == "UTF-8") {
+                recoded = result;
+              } else
+                recoded = recoder.process_recipe(result);
               m_database.insert_recipe(recoded);
               success++;
             } catch (parse_exception &e) {
@@ -134,7 +139,7 @@ void MainWindow::import(void) {
               error_file.flush();
               if (!error_file) {
                 ostringstream s;
-                s << tr("Error writing to file ").toUtf8().constData() << import_dialog.error_file();
+                s << tr("Error writing to file ").toUtf8().constData() << m_import_dialog.error_file();
                 throw gui_exception(s.str());
               };
             };
@@ -183,6 +188,10 @@ EditMode MainWindow::editing_mode(void) {
   return EDIT_CANCEL;
 }
 
+void MainWindow::new_recipe(void) {
+  edit_recipe(EDIT_NEW);
+}
+
 void MainWindow::edit(void) {
   EditMode mode;
   QModelIndex index = m_ui.titles_view->currentIndex();
@@ -190,15 +199,21 @@ void MainWindow::edit(void) {
     mode = editing_mode();
     if (mode == EDIT_CANCEL)
       return;
-  } else {
+  } else
     mode = EDIT_NEW;
-  };
+  edit_recipe(mode);
+}
+
+void MainWindow::edit_recipe(EditMode mode)
+{
   Recipe recipe;
-  sqlite3_int64 recipe_id;
+  sqlite3_int64 recipe_id = 0;
+  QModelIndex index = m_ui.titles_view->currentIndex();
   if (index.isValid() && mode != EDIT_NEW) {
     recipe_id = m_titles_model->recipeid(index);
     recipe = m_database.fetch_recipe(recipe_id);
-  };
+  } else if (mode == EDIT_CURRENT)
+    return;
   EditDialog edit_dialog(this);
   edit_dialog.set_recipe(recipe);
   if (edit_dialog.exec() == QDialog::Accepted) {
@@ -209,6 +224,7 @@ void MainWindow::edit(void) {
       m_database.begin();
       transaction = true;
       if (mode == EDIT_CURRENT) {
+        assert(recipe_id != 0);
         vector<sqlite3_int64> ids;
         ids.push_back(recipe_id);
         m_database.delete_recipes(ids);
@@ -311,7 +327,7 @@ void MainWindow::open_converter(void) {
 
 void MainWindow::about(void) {
   QMessageBox::information(this, tr("About AnyMeal %1").arg(PACKAGE_VERSION), "AnyMeal recipe management software\n"
-      "Copyright © 2002 to 2021  Jan Wedekind\n\n"
+      "Copyright © 2002 to 2023  Jan Wedekind\n\n"
       "This program is free software: you can redistribute it and/or modify "
       "it under the terms of the GNU General Public License as published by "
       "the Free Software Foundation, either version 3 of the License, or "
@@ -415,9 +431,8 @@ void MainWindow::export_recipes(void) {
   vector<sqlite3_int64> ids = recipe_ids();
   if (!ids.empty()) {
     try {
-      ExportDialog export_dialog(this);
-      int result = export_dialog.exec();
-      Recoder recoder((string("UTF-8..") + export_dialog.encoding()).c_str());
+      int result = m_export_dialog.exec();
+      Recoder recoder("UTF-8", m_export_dialog.encoding().c_str());
       if (result == QDialog::Accepted) {
         QString result =
           QFileDialog::getSaveFileName(this, tr("Export MealMaster File"), "", tr("MealMaster (*.mm *.MM *.mmf *.MMF);;"
@@ -425,6 +440,7 @@ void MainWindow::export_recipes(void) {
         if (!result.isEmpty()) {
           int success = 0;
           int failed = 0;
+          ofstream error_file(m_export_dialog.error_file().c_str(), ofstream::binary);
           ofstream output_file(result.toUtf8().constData());
           QProgressDialog progress(tr("Exporting recipes ..."), tr("Cancel"), 0, ids.size(), this);
           progress.setWindowModality(Qt::WindowModal);
@@ -433,7 +449,11 @@ void MainWindow::export_recipes(void) {
             sqlite3_int64 id = ids[i];
             Recipe recipe = m_database.fetch_recipe(id);
             try {
-              Recipe recoded = recoder.process_recipe(recipe);
+              Recipe recoded;
+              if (m_export_dialog.encoding() == "UTF-8") {
+                recoded = recipe;
+              } else
+                recoded = recoder.process_recipe(recipe);
               string txt = recipe_to_mealmaster(recoded);
               output_file << txt << "\r\n";
               success++;
@@ -441,6 +461,14 @@ void MainWindow::export_recipes(void) {
                 output_file << "\r\n";
             } catch (recode_exception &e) {
               failed++;
+              error_file << tr("Failed recipe: ").toUtf8().constData() << e.what() << "\r\n";
+              error_file << recipe_to_mealmaster(recipe) << "\r\n";
+              error_file.flush();
+              if (!error_file) {
+                ostringstream s;
+                s << tr("Error writing to file ").toUtf8().constData() << m_import_dialog.error_file();
+                throw gui_exception(s.str());
+              };
             };
             if (progress.wasCanceled())
               break;
@@ -510,3 +538,33 @@ void MainWindow::render(QPrinter *printer) {
   text_browser.print(printer);
   QGuiApplication::restoreOverrideCursor();
 }
+
+void MainWindow::remove_duplicates(void) {
+  vector<sqlite3_int64> ids = recipe_ids();
+  set<string> recipes;
+  vector<sqlite3_int64> recipes_to_delete;
+  QProgressDialog progress(tr("Detecting duplicates ..."), tr("Cancel"), 0, ids.size(), this);
+  progress.setWindowModality(Qt::WindowModal);
+  for (unsigned int i=0; i<ids.size(); i++) {
+    progress.setLabelText(tr("Found %1 duplicates ...").arg(recipes_to_delete.size()));
+    progress.setValue(i);
+    sqlite3_int64 id = ids[i];
+    Recipe recipe = m_database.fetch_recipe(id);
+    string txt = recipe_to_mealmaster(recipe);
+    if (recipes.find(txt) != recipes.end())
+      recipes_to_delete.push_back(id);
+    else
+      recipes.insert(txt);
+    if (progress.wasCanceled())
+      break;
+  };
+  if (!progress.wasCanceled()) {
+    QGuiApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    m_database.begin();
+    m_database.delete_recipes(recipes_to_delete);
+    m_database.commit();
+    m_titles_model->reset();
+    m_categories_model->reset();
+    QGuiApplication::restoreOverrideCursor();
+  };
+}
