@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'export_dialog.hh'
 **
-** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.2)
+** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.8)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -13,7 +13,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'export_dialog.hh' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 67
-#error "This file was generated using the moc from 5.15.2. It"
+#error "This file was generated using the moc from 5.15.8. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -22,8 +22,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_ExportDialog_t {
-    QByteArrayData data[1];
-    char stringdata0[13];
+    QByteArrayData data[3];
+    char stringdata0[32];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -32,10 +32,12 @@ struct qt_meta_stringdata_ExportDialog_t {
     )
 static const qt_meta_stringdata_ExportDialog_t qt_meta_stringdata_ExportDialog = {
     {
-QT_MOC_LITERAL(0, 0, 12) // "ExportDialog"
+QT_MOC_LITERAL(0, 0, 12), // "ExportDialog"
+QT_MOC_LITERAL(1, 13, 17), // "select_error_file"
+QT_MOC_LITERAL(2, 31, 0) // ""
 
     },
-    "ExportDialog"
+    "ExportDialog\0select_error_file\0"
 };
 #undef QT_MOC_LITERAL
 
@@ -45,22 +47,33 @@ static const uint qt_meta_data_ExportDialog[] = {
        8,       // revision
        0,       // classname
        0,    0, // classinfo
-       0,    0, // methods
+       1,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
        0,       // signalCount
 
+ // slots: name, argc, parameters, tag, flags
+       1,    0,   19,    2, 0x0a /* Public */,
+
+ // slots: parameters
+    QMetaType::Void,
+
        0        // eod
 };
 
 void ExportDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
-    Q_UNUSED(_o);
-    Q_UNUSED(_id);
-    Q_UNUSED(_c);
-    Q_UNUSED(_a);
+    if (_c == QMetaObject::InvokeMetaMethod) {
+        auto *_t = static_cast<ExportDialog *>(_o);
+        (void)_t;
+        switch (_id) {
+        case 0: _t->select_error_file(); break;
+        default: ;
+        }
+    }
+    (void)_a;
 }
 
 QT_INIT_METAOBJECT const QMetaObject ExportDialog::staticMetaObject = { {
@@ -89,6 +102,17 @@ void *ExportDialog::qt_metacast(const char *_clname)
 int ExportDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = QDialog::qt_metacall(_c, _id, _a);
+    if (_id < 0)
+        return _id;
+    if (_c == QMetaObject::InvokeMetaMethod) {
+        if (_id < 1)
+            qt_static_metacall(this, _c, _id, _a);
+        _id -= 1;
+    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
+        if (_id < 1)
+            *reinterpret_cast<int*>(_a[0]) = -1;
+        _id -= 1;
+    }
     return _id;
 }
 QT_WARNING_POP
