@@ -1,3 +1,18 @@
+/* AnyMeal recipe management software
+   Copyright (C) 2021, 2023 Jan Wedekind
+
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <https://www.gnu.org/licenses/>. */
 #include <fstream>
 #include <sstream>
 #include <gtest/gtest.h>
@@ -158,7 +173,9 @@ TEST(MealMasterTest, Instructions4) {
 
 TEST(MealMasterTest, Instructions5) {
   ifstream f("fixtures/instructions5.mmf");
-  EXPECT_THROW(parse_mealmaster(f), parse_exception);
+  Recipe result = parse_mealmaster(f);
+  ASSERT_EQ(1, result.ingredients().size());
+  EXPECT_EQ("-", result.ingredients()[0].text());
 }
 
 TEST(MealMasterTest, Instructions6) {
@@ -293,7 +310,9 @@ TEST(MealMasterTest, AppendToLine) {
 
 TEST(MealMasterTest, StrayIngredientLine) {
   ifstream f("fixtures/stray_ingredient.mmf");
-  EXPECT_THROW(parse_mealmaster(f), parse_exception);
+  Recipe result = parse_mealmaster(f);
+  ASSERT_EQ(1, result.instructions().size());
+  EXPECT_EQ("First line. 200.0 ml milk", result.instructions()[0]);
 }
 
 TEST(MealMasterTest, AcceptIngredientLikeLine) {
@@ -498,8 +517,18 @@ TEST(MealMasterTest, SectionWithTrailingWhitespace) {
   EXPECT_EQ("meringue", section.second);
 }
 
+TEST(MealMasterTest, UnexpectedContinuation) {
+  ifstream f("fixtures/unexpected_continuation.mmf");
+  Recipe result = parse_mealmaster(f);
+  ASSERT_EQ(1, result.ingredients().size());
+  EXPECT_EQ("-John Doe-", result.ingredients()[0].text());
+}
+
 TEST(MealMasterTest, ErroneousContinuation) {
   ifstream f("fixtures/erroneous_continuation.mmf");
+  Recipe result = parse_mealmaster(f);
+  ASSERT_EQ(2, result.ingredients().size());
+  EXPECT_EQ("-and stirred", result.ingredients()[1].text());
   EXPECT_THROW(parse_mealmaster(f), parse_exception);
 }
 
